@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 12823 2021-03-31 12:51:48Z Lavender $
+# $Id: models.py 12892 2021-05-06 08:01:00Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-03-31 20:51:48 +0800 (週三, 31 三月 2021) $
-# $Revision: 12823 $
+# $Date: 2021-05-06 16:01:00 +0800 (週四, 06 五月 2021) $
+# $Revision: 12892 $
 
 from emencia.django.newsletter.models import Newsletter, Contact
 
@@ -63,7 +63,7 @@ class BlackContact(models.Model):
     reason = models.TextField(_('Reason'))
     createdTime = models.DateTimeField(_('Created time'), auto_now_add=False)
     source = models.CharField(_('Source'), max_length=255, null=True)
-    mail = models.CharField(_('Mail'), max_length=255, null=True)
+    mail = models.CharField(_('SMTP Server'), max_length=255, null=True)
     
     class Meta:
         verbose_name = _('BlackContact')
